from userena.tests.test_backends import *
from userena.tests.test_commands import *
from userena.tests.tests_decorators import *
from userena.tests.tests_forms import *
from userena.tests.tests_managers import *
from userena.tests.tests_middleware import *
from userena.tests.tests_models import *
from userena.tests.test_privacy import *
from userena.tests.tests_utils import *
from userena.tests.tests_views import *
